pub struct RemoteEntry {
pub name: String,
pub uri: String,
pub disabled: bool,
}Expand description
A single entry in blit.remotes. disabled entries are persisted as
# name = uri and are excluded from connection resolution but preserved
across restarts so users can re-enable them later.
Fields
name: Stringuri: Stringdisabled: boolTrait Implementations
Sourceimpl Clone for RemoteEntry
impl Clone for RemoteEntry
Sourcefn clone(&self) -> RemoteEntry
fn clone(&self) -> RemoteEntry
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RemoteEntry
impl Debug for RemoteEntry
Sourceimpl PartialEq for RemoteEntry
impl PartialEq for RemoteEntry
Sourcefn eq(&self, other: &RemoteEntry) -> bool
fn eq(&self, other: &RemoteEntry) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for RemoteEntry
impl StructuralPartialEq for RemoteEntry